@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Generator, List, Optional, Union, Callable, TYPE_CHECKING
 from uuid import uuid4
-from math import inf, round
+from math import inf
 import warnings
 
 from Akatosh import Timeline, Mundus
@@ -80,8 +80,10 @@ class Actor:
 
         if callable(till):
             self._till = till
-        else:
+        elif till is not None:
             self._till = round(till, 3)
+        else:
+            self._till = till
 
         # initialize the status
         self._status = list()
